/**
 * @file mipsolver.h
 *
 * This file contains the declaration of the abstract class MipSolver. 
 *
 * Copyright (C) 2013 by Autodesk, Inc. All Rights Reserved.
 *
 * The information contained herein is confidential, proprietary
 * to Autodesk, Inc.,  and considered a trade  secret as defined
 * in section 499C of the penal code of the State of California.
 * Use  of  this  information  by  anyone other  than authorized
 * employees of Autodesk, Inc.  is granted  only under a written
 * non-disclosure  agreement,  expressly  prescribing  the scope
 * and manner of such use.
 *
 * AUTODESK  MAKES  NO  WARRANTIES,  EXPRESS  OR  IMPLIED, AS  TO THE
 * CORRECTNESS OF THIS CODE OR ANY DERIVATIVE WORKS WHICH INCORPORATE
 * IT. AUTODESK PROVIDES THE CODE ON AN  "AS-IS" BASIS AND EXPLICITLY
 * DISCLAIMS ANY  LIABILITY, INCLUDING  CONSEQUENTIAL AND  INCIDENTAL
 * DAMAGES  FOR ERRORS,  OMISSIONS,  AND OTHER  PROBLEMS IN THE CODE.
 *
 * Use, duplication, or disclosure by the U.S. Government is subject
 * to restrictions set forth in  FAR 52.227-19  (Commercial Computer
 * Software  Restricted  Rights)  and  DFAR   252.227-7013(c)(1)(ii)
 * (Rights in Technical Data and Computer Software),  as applicable.
 *
 * @author: Valentin Koch <valentin.koch@autodesk.com>
 */
#ifndef MIP_SOLVER_H_
#define MIP_SOLVER_H_

#include "lpsolver.h"

namespace aop
{


/**
 * @class MipSolver
 *
 * This abstract class represents an MILP solver. It's purpose is to use different
 * brands of MILP solvers for the same problem instance. This allows an easy switch
 * from one brand of solver to another.
 */
class MipSolver : public LpSolver
{
public:
	/// Initializes a new, empty model.
	MipSolver() {};
	/// Destructor. Must be virtual.
	virtual ~MipSolver() {};

	/// Add discrete variable with lower bound lb, upper bound ub, and cost cost.
	virtual void add_var_integer(const double lb, const double ub,
				     const double cost, const std::string& name = "") = 0;

	/// Add binary variable with lower bound lb, upper bound ub, and cost cost.
	virtual void add_var_binary(const double cost, const std::string& name = "") = 0;

};


} // namespace aop

#endif
